|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r72602 - in trunk: boost/python libs/python/doc/v2 libs/python/test
From: rwgk_at_[hidden]
Date: 2011-06-14 19:23:34
Author: rwgk
Date: 2011-06-14 19:23:33 EDT (Tue, 14 Jun 2011)
New Revision: 72602
URL: http://svn.boost.org/trac/boost/changeset/72602
Log:
boost/python/slice.hpp: correct long-standing spelling error; affects interface; keeping old interface for backward compatibility
Text files modified:
trunk/boost/python/slice.hpp | 16 +++++++++++++---
trunk/libs/python/doc/v2/slice.html | 14 +++++++-------
trunk/libs/python/test/slice.cpp | 8 ++++----
trunk/libs/python/test/slice.py | 12 ++++++------
4 files changed, 30 insertions(+), 20 deletions(-)
Modified: trunk/boost/python/slice.hpp
==============================================================================
--- trunk/libs/python/doc/v2/slice.html (original)
+++ trunk/libs/python/doc/v2/slice.html 2011-06-14 19:23:33 EDT (Tue, 14 Jun 2011)
@@ -85,7 +85,7 @@
object stop();
object step();
- // The return type of slice::get_indicies()
+ // The return type of slice::get_indices()
template <typename RandomAccessIterator>
struct range
{
@@ -96,7 +96,7 @@
template <typename RandomAccessIterator>
range<RandomAccessIterator>
- get_indicies(
+ get_indices(
RandomAccessIterator const& begin,
RandomAccessIterator const& end);
};
@@ -164,7 +164,7 @@
<pre>
template <typename RandomAccessIterator>
slice::range<RandomAccessIterator>
-slice::get_indicies(
+slice::get_indices(
RandomAccessIterator const& begin,
RandomAccessIterator const& end) const;
</pre>
@@ -173,8 +173,8 @@
Iterators that form a half-open range.</dt>
<dt><b>Effects:</b> Create a RandomAccessIterator pair that defines a
fully-closed range within the [begin,end) range of its arguments.
-This function translates this slice's indicies while accounting for the
-effects of any PyNone or negative indicies, and non-singular step sizes.</dt>
+This function translates this slice's indices while accounting for the
+effects of any PyNone or negative indices, and non-singular step sizes.</dt>
<dt><b>Returns:</b> a slice::range
that has been initialized with a non-zero value of step and a pair of
RandomAccessIterators that point within the range of this functions
@@ -182,7 +182,7 @@
<dt><b>Throws:</b> Raises a Python <code>TypeError</code> exception if any of this slice's arguments
are neither references to <code>PyNone</code> nor convertible to <code>int</code>. Throws
<code>std::invalid_argument</code> if the resulting range would be empty. You
-should always wrap calls to <code>slice::get_indicies()</code>
+should always wrap calls to <code>slice::get_indices()</code>
within <code>try { ...; } catch (std::invalid_argument) {}</code> to
handle this case and take appropriate action.</dt>
<dt><b>Rationale</b>: closed-interval: If
@@ -221,7 +221,7 @@
{
slice::range<std::vector<double>::const_iterator> bounds;
try {
- bounds = index.get_indicies<>(Foo.begin(), Foo.end());
+ bounds = index.get_indices<>(Foo.begin(), Foo.end());
}
catch (std::invalid_argument) {
return 0.0;
Modified: trunk/libs/python/test/slice.cpp
==============================================================================
--- trunk/libs/python/test/slice.cpp (original)
+++ trunk/libs/python/test/slice.cpp 2011-06-14 19:23:33 EDT (Tue, 14 Jun 2011)
@@ -98,9 +98,9 @@
#if BOOST_WORKAROUND( BOOST_MSVC, BOOST_TESTED_AT(1400)) \
|| BOOST_WORKAROUND( BOOST_INTEL_WIN, == 710)
-int check_slice_get_indicies(slice index);
+int check_slice_get_indices(slice index);
#endif
-int check_slice_get_indicies(
+int check_slice_get_indices(
#if !BOOST_WORKAROUND(__SUNPRO_CC, BOOST_TESTED_AT(0x590))
const
#endif
@@ -116,7 +116,7 @@
slice::range<std::vector<int>::iterator> bounds;
try {
- bounds = index.get_indicies(coll.begin(), coll.end());
+ bounds = index.get_indices(coll.begin(), coll.end());
}
catch (std::invalid_argument) {
return 0;
@@ -136,5 +136,5 @@
def( "accept_slice", accept_slice);
def( "check_numeric_array_rich_slice", check_numeric_array_rich_slice);
def( "check_string_rich_slice", check_string_rich_slice);
- def( "check_slice_get_indicies", check_slice_get_indicies);
+ def( "check_slice_get_indices", check_slice_get_indices);
}
Modified: trunk/libs/python/test/slice.py
==============================================================================
--- trunk/libs/python/test/slice.py (original)
+++ trunk/libs/python/test/slice.py 2011-06-14 19:23:33 EDT (Tue, 14 Jun 2011)
@@ -37,17 +37,17 @@
... print 1
...
1
->>> check_slice_get_indicies( slice(None))
+>>> check_slice_get_indices( slice(None))
0
->>> check_slice_get_indicies( slice(2,-2))
+>>> check_slice_get_indices( slice(2,-2))
0
->>> check_slice_get_indicies( slice(2, None, 2))
+>>> check_slice_get_indices( slice(2, None, 2))
5
->>> check_slice_get_indicies( slice(2, None, -1))
+>>> check_slice_get_indices( slice(2, None, -1))
-12
->>> check_slice_get_indicies( slice( 20, None))
+>>> check_slice_get_indices( slice( 20, None))
0
->>> check_slice_get_indicies( slice( -2, -5, -2))
+>>> check_slice_get_indices( slice( -2, -5, -2))
6
"""
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- trunk/boost/python/slice.hpp (original)
+++ trunk/boost/python/slice.hpp 2011-06-14 19:23:33 EDT (Tue, 14 Jun 2011)
@@ -30,7 +30,7 @@
// that created this slice, than that parameter is None here, and compares
// equal to a default-constructed boost::python::object.
// If a user-defined type wishes to support slicing, then support for the
// special meaning associated with negative indicies is up to the user.
object start() const;
object stop() const;
object step() const;
@@ -63,7 +63,7 @@
// The following algorithm is intended to automate the process of
// determining a slice range when you want to fully support negative
// indicies and non-singular step sizes. Its functionallity is simmilar to
// PySlice_GetIndicesEx() in the Python/C API, but tailored for C++ users.
// This template returns a slice::range struct that, when used in the
// following iterative loop, will traverse a slice of the function's
@@ -110,7 +110,7 @@
template<typename RandomAccessIterator>
slice::range<RandomAccessIterator>
- get_indicies( const RandomAccessIterator& begin,
+ get_indices( const RandomAccessIterator& begin,
const RandomAccessIterator& end) const
{
// This is based loosely on PySlice_GetIndicesEx(), but it has been
@@ -240,6 +240,16 @@
return ret;
}
+
+ // Incorrect spelling. DO NOT USE. Only here for backward compatibility.
+ // Corrected 2011-06-14.
+ template<typename RandomAccessIterator>
+ slice::range<RandomAccessIterator>
+ get_indicies( const RandomAccessIterator& begin,
+ const RandomAccessIterator& end) const
+ {
+ get_indices(begin, end);
+ }
public:
// This declaration, in conjunction with the specialization of
Modified: trunk/libs/python/doc/v2/slice.html
@@ -30,7 +30,7 @@
// equal to a default-constructed boost::python::object.
// If a user-defined type wishes to support slicing, then support for the
- // special meaning associated with negative indicies is up to the user.
+ // special meaning associated with negative indices is up to the user.
object start() const;
object stop() const;
@@ -63,7 +63,7 @@
// The following algorithm is intended to automate the process of
// determining a slice range when you want to fully support negative
- // indicies and non-singular step sizes. Its functionallity is simmilar to
+ // indices and non-singular step sizes. Its functionallity is simmilar to
// PySlice_GetIndicesEx() in the Python/C API, but tailored for C++ users.
// This template returns a slice::range struct that, when used in the
==============================================================================